/**
 * This generic class provides methods to manage, add and delete a list of lists of elements and to check dependency
 * between those elements.
 * 
 * @author Boris Serdar
 * 
 * @param <A>
 *            Type parameter for the elements contained in the list.
 * @param <B>
 *            Type parameter for the elements contained in the list of lists.
 */
public class DList<A extends Dependent<? super A>, B> extends AList<A, B> {
	
	/**
	 * This method checks consistency of the current object.
	 * Consistency: No element is dependent (dependsOn) of any following element!
	 * 
	 * @return true if consistent, false otherwise.
	 */
	public boolean consistent() {
		Node current = head;
		while (current != null) {

			Node temp = current.next;
			while (temp != null) {
				if (current.elem.dependsOn(temp.elem) == true) {
					return false;
				}

				temp = temp.next;
			}

			current = current.next;
		}
		
		return true;
	}
}
